@@ -307,29 +307,6 @@ QString ResourceState::rootRemoteId() const
   return Settings::self()->rootRemoteId();
 }
 
-QString ResourceState::mailBoxForCollection( const Akonadi::Collection &collection, bool showWarnings ) const
-{
-  if ( collection.remoteId().isEmpty() ) { //This should never happen, investigate why a collection without remoteId made it this far
-    if ( showWarnings )
-      kWarning() << "Got incomplete ancestor chain due to empty remoteId:" << collection;
-    return QString();
-  }
-
-  if ( collection.parentCollection() == Akonadi::Collection::root() ) {
-    if ( showWarnings )
-      kWarning( collection.remoteId() != rootRemoteId() ) << "RID mismatch, is " << collection.remoteId() << " expected " << rootRemoteId();
-    return QString( "" );
-  }
-  const QString parentMailbox = mailBoxForCollection( collection.parentCollection() );
-  if ( parentMailbox.isNull() ) // invalid, != isEmpty() here!
-    return QString();
-
-  const QString mailbox =  parentMailbox + collection.remoteId();
-  if ( parentMailbox.isEmpty() )
-    return mailbox.mid( 1 ); // strip of the separator on top-level mailboxes
-  return mailbox;
-}
-
 void ResourceState::setIdleCollection( const Akonadi::Collection &collection )
 {
   QStringList ridPath;
@@ -506,6 +483,16 @@ void ResourceState::scheduleConnectionAttempt()
   m_resource->scheduleConnectionAttempt();
 }
 
+QChar ResourceState::separatorCharacter() const
+{
+  return m_resource->separatorCharacter();
+}
+
+void ResourceState::setSeparatorCharacter( const QChar &separator )
+{
+  m_resource->setSeparatorCharacter( separator );
+}
+
 void ResourceState::showInformationDialog( const QString &message, const QString &title, const QString &dontShowAgainName )
 {
   KMessageBox::information( 0, message, title, dontShowAgainName );
