@@ -154,12 +154,34 @@ SubscriptionDialog::SubscriptionDialog( QWidget *parent, SubscriptionDialog::Sub
   } else {
     m_enableSubscription->hide();
   }
+  readConfig();
 }
 
 SubscriptionDialog::~SubscriptionDialog()
 {
+  writeConfig();
 }
 
+void SubscriptionDialog::readConfig()
+{
+  KConfigGroup group( KGlobal::config(), "SubscriptionDialog" );
+
+  const QSize size = group.readEntry( "Size", QSize() );
+  if ( size.isValid() ) {
+      resize( size );
+  } else {
+      resize( 500, 300 );
+  }
+}
+
+void SubscriptionDialog::writeConfig()
+{
+  KConfigGroup group( KGlobal::config(), "SubscriptionDialog" );
+  group.writeEntry( "Size", size() );
+  group.sync();
+}
+
+
 void SubscriptionDialog::setSubscriptionEnabled( bool enabled )
 {
   m_enableSubscription->setChecked( enabled );
