@@ -25,12 +25,12 @@
 #include "incidencehandler.h"
 
 /**
-	@author Andras Mantia <amantia@kde.org>
+        @author Andras Mantia <amantia@kde.org>
 */
 class JournalHandler : public IncidenceHandler
 {
   public:
-    JournalHandler( const Akonadi::Collection &imapCollection );
+    explicit JournalHandler( const Akonadi::Collection &imapCollection );
     virtual ~JournalHandler();
 
     virtual QStringList contentMimeTypes();
